You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [2/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LockedAccountException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LockedAccountException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LockedAccountException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LockedAccountException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 /**
  * A special kind of <tt>DisabledAccountException</tt>, this exception is thrown when attempting

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LogoutAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LogoutAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/MergableAuthenticationInfo.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/MergableAuthenticationInfo.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 /**
  * <p>An extension of the {@link AuthenticationInfo} interface to be implemented by

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/RememberMeAuthenticationToken.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/RememberMeAuthenticationToken.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/RememberMeAuthenticationToken.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/RememberMeAuthenticationToken.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 /**
  * An <tt>AuthenticationToken</tt> that indicates if the user wishes their identity to be remembered across sessions.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAccount.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAccount.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UnknownAccountException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UnknownAccountException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 /**
  * Thrown when attempting to authenticate with a principal that doesn't exist in the system (e.g.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UsernamePasswordToken.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UsernamePasswordToken.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
 
 /**
  * A credentials matcher that always returns <tt>true</tt> when matching credentials no matter what arguments
  * are passed in.  This can be used for testing or when credentials are implicitly trusted for a particular
- * {@link org.apache.ki.realm.Realm Realm}.
+ * {@link org.apache.shiro.realm.Realm Realm}.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/HashedCredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/HashedCredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md5CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md5CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Md5Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Md5Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha1CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Sha1Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Sha1Hash;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/package-info.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 /**
  * Support for validating <em>credentials</em> (such as passwords or X509 certificates) during
- * authentication via the {@link org.apache.ki.authc.credential.CredentialsMatcher CredentialsMatcher}
+ * authentication via the {@link org.apache.shiro.authc.credential.CredentialsMatcher CredentialsMatcher}
  * interface and its supporting implementations.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AtLeastOneSuccessfulStrategy.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AtLeastOneSuccessfulStrategy.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
 
 /**
  * <tt>AuthenticationStrategy</tt> implementation that requires <em>at least one</em> configured realm to
@@ -43,7 +43,7 @@
 
     /**
      * Ensures that the <code>aggregate</code> method argument is not <code>null</code> and
-     * <code>aggregate.{@link org.apache.ki.authc.AuthenticationInfo#getPrincipals() getPrincipals()}</code>
+     * <code>aggregate.{@link org.apache.shiro.authc.AuthenticationInfo#getPrincipals() getPrincipals()}</code>
      * is not <code>null</code>, and if either is <code>null</code>, throws an AuthenticationException to indicate
      * that none of the realms authenticated successfully.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AuthenticationStrategy.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AuthenticationStrategy.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/FirstSuccessfulStrategy.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/FirstSuccessfulStrategy.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import java.util.Collection;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.realm.Realm;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.realm.Realm;
 
 /**
  * {@link AuthenticationStrategy} implementation that only accepts the account data from

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/ModularRealmAuthenticator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/ModularRealmAuthenticator.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -27,7 +27,8 @@
  * @author Les Hazlewood
  * @since 0.1
  */
-public class AuthorizationException extends KiException {
+public class AuthorizationException extends ShiroException
+{
 
     /**
      * Creates a new AuthorizationException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationInfo.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationInfo.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/HostUnauthorizedException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/HostUnauthorizedException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.net.InetAddress;
 
@@ -26,7 +26,7 @@
  * or access a particular resource.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.session.mgt.SessionManager#start(java.net.InetAddress)
+ * @see org.apache.shiro.session.mgt.SessionManager#start(java.net.InetAddress)
  * @since 0.1
  */
 public class HostUnauthorizedException extends UnauthorizedException {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/ModularRealmAuthorizer.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/ModularRealmAuthorizer.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizationInfo.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizationInfo.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.util.Collection;
 import java.util.HashSet;
@@ -26,7 +26,7 @@
  * Simple POJO implementation of the {@link AuthorizationInfo} interface that stores roles and permissions as internal
  * attributes.
  *
- * @see org.apache.ki.realm.AuthorizingRealm
+ * @see org.apache.shiro.realm.AuthorizingRealm
  * @since 0.9
  * @author Jeremy Haile
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizingAccount.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizingAccount.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizingAccount.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizingAccount.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.util.Collection;
 import java.util.HashSet;
@@ -24,9 +24,9 @@
 import java.util.List;
 import java.util.Set;
 
-import org.apache.ki.authc.Account;
-import org.apache.ki.authc.SimpleAccount;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.Account;
+import org.apache.shiro.authc.SimpleAccount;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * <p>A simple implementation of the {@link AuthorizingAccount} interface that is useful

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleRole.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleRole.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleRole.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleRole.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.io.Serializable;
 import java.util.Collection;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthenticatedException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthenticatedException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthenticatedException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthenticatedException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 /**
  * Exception thrown when attempting to execute an authorization action when a successful

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthorizedException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthorizedException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthorizedException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/UnauthorizedException.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 /**
  * Thrown to indicate a requested operation or access to a requested resource is not allowed.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresAuthentication.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresAuthentication.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresGuest.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresGuest.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.annotation;
+package org.apache.shiro.authz.annotation;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -30,7 +30,7 @@
  * This annotation is the logical inverse of the {@link RequiresUser RequiresUser} annotation. That is,
  * <code>RequiresUser == !RequiresGuest</code>, or more accurately,
  * <p/>
- * <code>RequiresGuest === subject.{@link org.apache.ki.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
+ * <code>RequiresGuest === subject.{@link org.apache.shiro.subject.Subject#getPrincipal() getPrincipal()} == null</code>.
  *
  * @see RequiresAuthentication
  * @see RequiresUser
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LogoutAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/LogoutAware.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * An SPI interface allowing cleanup logic to be executed during logout of a previously authenticated Subject/user.
  *
  * <p>As it is an SPI interface, it is really intended for SPI implementors such as those implementing Realms.
  *
  * <p>All of Ki's concrete Realm implementations implement this interface as a convenience for those wishing
  * to subclass them.
  *
  * @author Les Hazlewood
@@ -16,16 +16,16 @@
  * <p>As it is an SPI interface, it is really intended for SPI implementors such as those implementing Realms.
  *
- * <p>All of Ki's concrete Realm implementations implement this interface as a convenience for those wishing
+ * <p>All of Shiro's concrete Realm implementations implement this interface as a convenience for those wishing
  * to subclass them.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/MergableAuthenticationInfo.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/MergableAuthenticationInfo.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAccount.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAccount.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Set;
 
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.SimpleAuthorizationInfo;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.SimplePrincipalCollection;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.SimpleAuthorizationInfo;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.SimplePrincipalCollection;
 
 
 /**
  * Simple implementation of the {@link org.apache.ki.authc.Account} interface that
  * contains principal and credential and authorization information (roles and permissions) as instance variables and
  * exposes them via getters and setters using standard JavaBean notation.
  *
@@ -54,13 +54,13 @@
 
     /**
      * Indicates this account is locked.  This isn't honored by all <tt>Realms</tt> but is honored by
-     * {@link org.apache.ki.realm.SimpleAccountRealm}.
+     * {@link org.apache.shiro.realm.SimpleAccountRealm}.
      */
     private boolean locked;
 
     /**
      * Indicates credentials on this account are expired.  This isn't honored by all <tt>Realms</tt> but is honored by
-     * {@link org.apache.ki.realm.SimpleAccountRealm}.
+     * {@link org.apache.shiro.realm.SimpleAccountRealm}.
      */
     private boolean credentialsExpired;
 
@@ -216,7 +216,7 @@
      * {@link #getPrincipals() principals}, such as a password or private key.
      *
      * @param credentials the credentials associated with this Account that verify one or more of the Account principals.
-     * @see org.apache.ki.authc.Account#getCredentials()
+     * @see org.apache.shiro.authc.Account#getCredentials()
      */
     public void setCredentials(Object credentials) {
         this.authcInfo.setCredentials(credentials);
@@ -273,7 +273,7 @@
      * Sets the String-based permissions assigned to this Account.  Simply delegates to
      * <code>this.authzInfo.setStringPermissions(permissions)</code>.
      * @param permissions all String-based permissions assigned to this Account.
-     * @see org.apache.ki.authc.Account#getStringPermissions()
+     * @see org.apache.shiro.authc.Account#getStringPermissions()
      */
     public void setStringPermissions(Set<String> permissions) {
         this.authzInfo.setStringPermissions(permissions);
@@ -16,20 +16,20 @@
 
 /**
- * Simple implementation of the {@link org.apache.ki.authc.Account} interface that
+ * Simple implementation of the {@link org.apache.shiro.authc.Account} interface that
  * contains principal and credential and authorization information (roles and permissions) as instance variables and
  * exposes them via getters and setters using standard JavaBean notation.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAuthenticationInfo.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAuthenticationInfo.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAuthenticationInfo.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/SimpleAuthenticationInfo.java Thu Jun 18 03:13:34 2009
@@ -16,22 +16,22 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.Set;
 
-import org.apache.ki.subject.MutablePrincipalCollection;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.SimplePrincipalCollection;
+import org.apache.shiro.subject.MutablePrincipalCollection;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.SimplePrincipalCollection;
 
 
 /**
  * Simple implementation of the {@link org.apache.ki.authc.MergableAuthenticationInfo} interface that holds the principals and
  * credentials.
  *
- * @see org.apache.ki.realm.AuthenticatingRealm
+ * @see org.apache.shiro.realm.AuthenticatingRealm
  * @since 0.9
  * @author Jeremy Haile
  * @author Les Hazlewood
@@ -16,22 +16,22 @@
 
 /**
- * Simple implementation of the {@link org.apache.ki.authc.MergableAuthenticationInfo} interface that holds the principals and
+ * Simple implementation of the {@link org.apache.shiro.authc.MergableAuthenticationInfo} interface that holds the principals and
  * credentials.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UnknownAccountException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UnknownAccountException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UsernamePasswordToken.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/UsernamePasswordToken.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
 
 import java.net.InetAddress;
 
@@ -25,7 +25,7 @@
  * <p>A simple username/password authentication token to support the most widely-used authentication mechanism.  This
  * class also implements the {@link RememberMeAuthenticationToken RememberMeAuthenticationToken} interface to support
  * &quot;Remember Me&quot; services across user sessions as well as the
  * {@link org.apache.ki.authc.InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
  * authentication attempt is occuring.</p>
  *
  * <p>&quot;Remember Me&quot; authentications are disabled by default, but if the application developer wishes to allow
@@ -255,7 +255,7 @@
      * Simply returns {@link #getUsername() getUsername()}.
      *
      * @return the {@link #getUsername() username}.
-     * @see org.apache.ki.authc.AuthenticationToken#getPrincipal()
+     * @see org.apache.shiro.authc.AuthenticationToken#getPrincipal()
      */
     public Object getPrincipal() {
         return getUsername();
@@ -265,7 +265,7 @@
      * Returns the {@link #getPassword() password} char array.
      *
      * @return the {@link #getPassword() password} char array.
-     * @see org.apache.ki.authc.AuthenticationToken#getCredentials()
+     * @see org.apache.shiro.authc.AuthenticationToken#getCredentials()
      */
     public Object getCredentials() {
         return getPassword();
@@ -276,7 +276,7 @@
      * is unknown or explicitly omitted.  It is up to the Authenticator implementation processing this token if
      * an authentication attempt without an inetAddress is valid or not.
      *
-     * <p>(Ki's default Authenticator
+     * <p>(Shiro's default Authenticator
      * allows <tt>null</tt> IPs to support localhost and proxy server environments).</p>
      *
      * @return the inetAddress from where the authentication attempt occurs, or <tt>null</tt> if it is unknown or
@@ -291,7 +291,7 @@
      * Sets the inetAddress from where the authentication attempt occurs.  It is up to the Authenticator
      * implementation processing this token if an authentication attempt without an inetAddress is valid or not.
      *
-     * <p>(Ki's default Authenticator
+     * <p>(Shiro's default Authenticator
      * allows <tt>null</tt> IPs to allow localhost and proxy server environments).</p>
      *
      * @param inetAddress the inetAddress from where the authentication attempt occurs.
@@ -25,7 +25,7 @@
  * class also implements the {@link RememberMeAuthenticationToken RememberMeAuthenticationToken} interface to support
  * &quot;Remember Me&quot; services across user sessions as well as the
- * {@link org.apache.ki.authc.InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
+ * {@link org.apache.shiro.authc.InetAuthenticationToken InetAuthenticationToken} interface to retain the IP address location from where the
  * authentication attempt is occuring.</p>
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/AllowAllCredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/HashedCredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/HashedCredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
 
 /**
  * A <tt>HashedCredentialMatcher</tt> provides support for hashing of supplied <tt>AuthenticationToken</tt> credentials
@@ -48,8 +48,8 @@
  * salting and multiple iterations and why you might want to use them. (Note of sections 5
  * &quot;Why add salt?&quot; and 6 "Hardening against the attacker's attack").
  *
  * <p>We should also note here that all of Ki's Hash implementations (for example,
  * {@link org.apache.ki.crypto.hash.Md5Hash Md5Hash}, {@link org.apache.ki.crypto.hash.Sha1Hash Sha1Hash}, etc)
  * support salting and multiple hash iterations via overloaded constructors.</p>
  *
  * <h4>Salting</h4>
@@ -57,7 +57,7 @@
  * <p>Salting of the authentication token's credentials hash is disabled by default, but you may enable it by setting
  * {@link #setHashSalted hashSalted} to
  * <tt>true</tt>.  If you do enable it, the value used to salt the hash will be
- * obtained from {@link #getSalt(org.apache.ki.authc.AuthenticationToken) getSalt(authenticationToken)}.
+ * obtained from {@link #getSalt(org.apache.shiro.authc.AuthenticationToken) getSalt(authenticationToken)}.
  *
  * <p>The default <tt>getSalt</tt> implementation merely returns
  * <code>token.getPrincipal()</code>, effectively using the user's identity as the salt, a most common
@@ -76,9 +76,9 @@
  * supporting <code>CredentialsMatcher</code> implementations.</p>
  *
  * @author Les Hazlewood
  * @see org.apache.ki.crypto.hash.Md5Hash
  * @see org.apache.ki.crypto.hash.Sha1Hash
  * @see org.apache.ki.crypto.hash.Sha256Hash
  * @since 0.9
  */
 public abstract class HashedCredentialsMatcher extends SimpleCredentialsMatcher {
@@ -91,7 +91,7 @@
      * Returns <tt>true</tt> if the system's stored credential hash is Hex encoded, <tt>false</tt> if it
      * is Base64 encoded.
      *
-     * <p>Default value is <tt>true</tt> for convenience - all of Ki's {@link Hash Hash#toString()}
+     * <p>Default value is <tt>true</tt> for convenience - all of Shiro's {@link Hash Hash#toString()}
      * implementations return Hex encoded values by default, making this class's use with those implementations
      * easier.</p>
      *
@@ -108,7 +108,7 @@
      * <p>A value of <tt>true</tt> will cause this class to decode the system credential from Hex, a
      * value of <tt>false</tt> will cause this class to decode the system credential from Base64.</p>
      *
      * <p>Unless overridden via this method, the default value is <tt>true</tt> for convenience - all of Ki's
      * {@link Hash Hash#toString()} implementations return Hex encoded values by default, making this class's use with
      * those implementations easier.</p>.
      *
@@ -137,7 +137,7 @@
     /**
      * Sets whether or not to salt a submitted <tt>AuthenticationToken</tt>'s credentials when hashing.
      *
      * <p>If enabled, the salt used will be obtained via the {@link #getSalt(org.apache.ki.authc.AuthenticationToken) getSalt} method.
      *
      * <p>The default value is <tt>false</tt>.
      *
@@ -263,7 +263,7 @@
 
     /**
      * Returns a new, <em>uninitialized</em> instance, without its byte array set.  Used as a utility method in the
-     * {@link SimpleCredentialsMatcher#getCredentials(org.apache.ki.authc.AuthenticationInfo) getCredentials(AuthenticationInfo)} implementation.
+     * {@link SimpleCredentialsMatcher#getCredentials(org.apache.shiro.authc.AuthenticationInfo) getCredentials(AuthenticationInfo)} implementation.
      *
      * @return a new, <em>uninitialized</em> instance, without its byte array set.
      */
@@ -48,8 +48,8 @@
  * &quot;Why add salt?&quot; and 6 "Hardening against the attacker's attack").
  *
- * <p>We should also note here that all of Ki's Hash implementations (for example,
- * {@link org.apache.ki.crypto.hash.Md5Hash Md5Hash}, {@link org.apache.ki.crypto.hash.Sha1Hash Sha1Hash}, etc)
+ * <p>We should also note here that all of Shiro's Hash implementations (for example,
+ * {@link org.apache.shiro.crypto.hash.Md5Hash Md5Hash}, {@link org.apache.shiro.crypto.hash.Sha1Hash Sha1Hash}, etc)
  * support salting and multiple hash iterations via overloaded constructors.</p>
  *
@@ -76,9 +76,9 @@
  *
  * @author Les Hazlewood
- * @see org.apache.ki.crypto.hash.Md5Hash
- * @see org.apache.ki.crypto.hash.Sha1Hash
- * @see org.apache.ki.crypto.hash.Sha256Hash
+ * @see org.apache.shiro.crypto.hash.Md5Hash
+ * @see org.apache.shiro.crypto.hash.Sha1Hash
+ * @see org.apache.shiro.crypto.hash.Sha256Hash
  * @since 0.9
  */
@@ -108,7 +108,7 @@
      * value of <tt>false</tt> will cause this class to decode the system credential from Base64.</p>
      *
-     * <p>Unless overridden via this method, the default value is <tt>true</tt> for convenience - all of Ki's
+     * <p>Unless overridden via this method, the default value is <tt>true</tt> for convenience - all of Shiro's
      * {@link Hash Hash#toString()} implementations return Hex encoded values by default, making this class's use with
      * those implementations easier.</p>.
@@ -137,7 +137,7 @@
      * Sets whether or not to salt a submitted <tt>AuthenticationToken</tt>'s credentials when hashing.
      *
-     * <p>If enabled, the salt used will be obtained via the {@link #getSalt(org.apache.ki.authc.AuthenticationToken) getSalt} method.
+     * <p>If enabled, the salt used will be obtained via the {@link #getSalt(org.apache.shiro.authc.AuthenticationToken) getSalt} method.
      *
      * <p>The default value is <tt>false</tt>.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md2CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md2CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md2CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md2CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Md2Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Md2Hash;
 
 
 /**
@@ -41,7 +41,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Md2Hash Md2Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Md2Hash();
@@ -49,7 +49,7 @@
 
     /**
      * This implementation merely returns
-     * <code>new {@link org.apache.ki.crypto.hash.Md2Hash#Md2Hash(Object, Object, int) Md2Hash(credentials,salt,hashIterations)}</code>.
+     * <code>new {@link org.apache.shiro.crypto.hash.Md2Hash#Md2Hash(Object, Object, int) Md2Hash(credentials,salt,hashIterations)}</code>.
      */
     protected Hash hashProvidedCredentials(Object credentials, Object salt, int hashIterations) {
         return new Md2Hash(credentials, salt, hashIterations);
@@ -41,7 +41,7 @@
      * Creates a new <em>uninitialized</em> {@link Md2Hash Md2Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Md2Hash Md2Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.shiro.crypto.hash.Md2Hash Md2Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md5CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Md5CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha256CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Sha256Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Sha256Hash;
 
 
 /**
@@ -35,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha256Hash Sha256Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha256Hash();
@@ -35,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha256Hash Sha256Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha256Hash Sha256Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.shiro.crypto.hash.Sha256Hash Sha256Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha384CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Sha384Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Sha384Hash;
 
 
 /**
@@ -35,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha384Hash Sha384Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha384Hash();
@@ -35,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha384Hash Sha384Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha384Hash Sha384Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.shiro.crypto.hash.Sha384Hash Sha384Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/Sha512CredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,11 +16,11 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
-import org.apache.ki.crypto.hash.AbstractHash;
-import org.apache.ki.crypto.hash.Hash;
-import org.apache.ki.crypto.hash.Sha512Hash;
+import org.apache.shiro.crypto.hash.AbstractHash;
+import org.apache.shiro.crypto.hash.Hash;
+import org.apache.shiro.crypto.hash.Sha512Hash;
 
 
 /**
@@ -35,7 +35,7 @@
     /**
      * Creates a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
      *
      * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha512Hash Sha512Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {
         return new Sha512Hash();
@@ -35,7 +35,7 @@
      * Creates a new <em>uninitialized</em> {@link Sha512Hash Sha512Hash} instance, without it's byte array set.
      *
-     * @return a new <em>uninitialized</em> {@link org.apache.ki.crypto.hash.Sha512Hash Sha512Hash} instance, without it's byte array set.
+     * @return a new <em>uninitialized</em> {@link org.apache.shiro.crypto.hash.Sha512Hash Sha512Hash} instance, without it's byte array set.
      */
     protected AbstractHash newHashInstance() {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/SimpleCredentialsMatcher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/SimpleCredentialsMatcher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/SimpleCredentialsMatcher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/SimpleCredentialsMatcher.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.credential;
+package org.apache.shiro.authc.credential;
 
 import java.util.Arrays;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.codec.CodecSupport;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.codec.CodecSupport;
 
 
 /**
@@ -34,11 +34,11 @@
  * <code>Object.equals</code> comparison.
  *
  * <p>Hashing comparisons (the most common technique used in secure applications) are not supported by this class, but
  * instead by {@link org.apache.ki.authc.credential.HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.authc.credential.HashedCredentialsMatcher
- * @see org.apache.ki.authc.credential.Md5CredentialsMatcher
+ * @see org.apache.shiro.authc.credential.HashedCredentialsMatcher
+ * @see org.apache.shiro.authc.credential.Md5CredentialsMatcher
  * @see Sha1CredentialsMatcher
  * @since 0.9
  */
@@ -118,7 +118,7 @@
      * This implementation acquires the <tt>token</tt>'s credentials
      * (via {@link #getCredentials(AuthenticationToken) getCredentials(token)})
      * and then the <tt>account</tt>'s credentials
      * (via {@link #getCredentials(org.apache.ki.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
      * them to the {@link #equals(Object,Object) equals(tokenCredentials, accountCredentials)} method for equality
      * comparison.
      *
@@ -34,11 +34,11 @@
  *
  * <p>Hashing comparisons (the most common technique used in secure applications) are not supported by this class, but
- * instead by {@link org.apache.ki.authc.credential.HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
+ * instead by {@link org.apache.shiro.authc.credential.HashedCredentialsMatcher HashedCredentialsMatcher} implementations.
  *
  * @author Les Hazlewood
@@ -118,7 +118,7 @@
      * (via {@link #getCredentials(AuthenticationToken) getCredentials(token)})
      * and then the <tt>account</tt>'s credentials
-     * (via {@link #getCredentials(org.apache.ki.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
+     * (via {@link #getCredentials(org.apache.shiro.authc.AuthenticationInfo) getCredentials(account)}) and then passes both of
      * them to the {@link #equals(Object,Object) equals(tokenCredentials, accountCredentials)} method for equality
      * comparison.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/credential/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/package-info.java Thu Jun 18 03:13:34 2009
@@ -19,11 +19,11 @@
 /**
  * Core interfaces and exceptions concerning Authentication (the act of logging-in).
  * <p/>
  * Ki abbreviates the word 'AuthentiCation' as <tt>authc</tt> to distinguish it seperately from
  * 'AuthoriZation', abbreviated as <tt>authz</tt>.
  * <p/>
  * The primary item of interest in this package is the <tt>Authenticator</tt> interface, which acts as the
  * entry point (facade) to all other other authentication components. Other components, interfaces and
  * exceptions are here to support <tt>Authenticator</tt> implementations.
  */
-package org.apache.ki.authc;
+package org.apache.shiro.authc;
@@ -19,11 +19,11 @@
  * Core interfaces and exceptions concerning Authentication (the act of logging-in).
  * <p/>
- * Ki abbreviates the word 'AuthentiCation' as <tt>authc</tt> to distinguish it seperately from
+ * Shiro abbreviates the word 'AuthentiCation' as <tt>authc</tt> to distinguish it seperately from
  * 'AuthoriZation', abbreviated as <tt>authz</tt>.
  * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AbstractAuthenticationStrategy.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AbstractAuthenticationStrategy.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AbstractAuthenticationStrategy.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AbstractAuthenticationStrategy.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import java.util.Collection;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.MergableAuthenticationInfo;
-import org.apache.ki.authc.SimpleAuthenticationInfo;
-import org.apache.ki.realm.Realm;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.MergableAuthenticationInfo;
+import org.apache.shiro.authc.SimpleAuthenticationInfo;
+import org.apache.shiro.realm.Realm;
 
 
 /**
  * Abstract base implementation for Ki's concrete <code>AuthenticationStrategy</code>
  * implementations.
  *
  * @author Jeremy Haile
@@ -39,7 +39,7 @@
 public abstract class AbstractAuthenticationStrategy implements AuthenticationStrategy {
 
     /**
      * Simply returns <code>new {@link org.apache.ki.authc.SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
      * aggregating account data across realms.
      */
     public AuthenticationInfo beforeAllAttempts(Collection<? extends Realm> realms, AuthenticationToken token) throws AuthenticationException {
@@ -77,11 +77,11 @@
      * aggregate for continued use throughout the login process.
      * <p/>
      * This implementation merely checks to see if the specified <code>aggregate</code> argument is an instance of
      * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
      * <code>aggregate.merge(info)</code>  If it is <em>not</em> an instance of
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
      * Can be overridden by subclasses for custom merging behavior if implementing the
      * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
      */
     protected AuthenticationInfo merge(AuthenticationInfo info, AuthenticationInfo aggregate) {
         if( aggregate instanceof MergableAuthenticationInfo ) {
@@ -16,20 +16,20 @@
 
 /**
- * Abstract base implementation for Ki's concrete <code>AuthenticationStrategy</code>
+ * Abstract base implementation for Shiro's concrete <code>AuthenticationStrategy</code>
  * implementations.
  *
@@ -39,7 +39,7 @@
 
     /**
-     * Simply returns <code>new {@link org.apache.ki.authc.SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
+     * Simply returns <code>new {@link org.apache.shiro.authc.SimpleAuthenticationInfo SimpleAuthenticationInfo}();</code>, which supports
      * aggregating account data across realms.
      */
@@ -77,11 +77,11 @@
      * <p/>
      * This implementation merely checks to see if the specified <code>aggregate</code> argument is an instance of
-     * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
+     * {@link org.apache.shiro.authc.MergableAuthenticationInfo MergableAuthenticationInfo}, and if so, calls
      * <code>aggregate.merge(info)</code>  If it is <em>not</em> an instance of
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
@@ -77,11 +77,11 @@
      * <code>MergableAuthenticationInfo</code>, an {@link IllegalArgumentException IllegalArgumentException} is thrown.
      * Can be overridden by subclasses for custom merging behavior if implementing the
-     * {@link org.apache.ki.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
+     * {@link org.apache.shiro.authc.MergableAuthenticationInfo MergableAuthenticationInfo} is not desired for some reason.
      */
     protected AuthenticationInfo merge(AuthenticationInfo info, AuthenticationInfo aggregate) {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AllSuccessfulStrategy.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AllSuccessfulStrategy.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AllSuccessfulStrategy.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AllSuccessfulStrategy.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.UnknownAccountException;
-import org.apache.ki.realm.Realm;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.UnknownAccountException;
+import org.apache.shiro.realm.Realm;
 
 
 /**
@@ -46,7 +46,7 @@
 
     /**
      * Because all realms in this strategy must complete successfully, this implementation ensures that the given
      * <code>Realm</code> {@link org.apache.ki.realm.Realm#supports(org.apache.ki.authc.AuthenticationToken) supports} the given
      * <code>token</code> argument.  If it does not, this method throws an
      * {@link UnsupportedTokenException UnsupportedTokenException} to end the authentication
      * process immediately. If the realm does support the token, the <code>info</code> argument is returned immediately.
@@ -46,7 +46,7 @@
     /**
      * Because all realms in this strategy must complete successfully, this implementation ensures that the given
-     * <code>Realm</code> {@link org.apache.ki.realm.Realm#supports(org.apache.ki.authc.AuthenticationToken) supports} the given
+     * <code>Realm</code> {@link org.apache.shiro.realm.Realm#supports(org.apache.shiro.authc.AuthenticationToken) supports} the given
      * <code>token</code> argument.  If it does not, this method throws an
      * {@link UnsupportedTokenException UnsupportedTokenException} to end the authentication

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AtLeastOneSuccessfulStrategy.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AtLeastOneSuccessfulStrategy.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AuthenticationStrategy.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/AuthenticationStrategy.java Thu Jun 18 03:13:34 2009
@@ -16,14 +16,14 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import java.util.Collection;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.realm.Realm;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.realm.Realm;
 
 
 /**
@@ -72,7 +72,7 @@
      * @param aggregate the aggregated AuthenticationInfo object being used across the multi-realm authentication attempt
      * @return the AuthenticationInfo object that will be presented to further realms in the authentication process - returning
      *         the <code>aggregate</code> method argument is the normal case if no special action needs to be taken.
      * @throws org.apache.ki.authc.AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
      *                                 process for the associated subject (user) to stop immediately.
      */
     AuthenticationInfo beforeAttempt(Realm realm, AuthenticationToken token, AuthenticationInfo aggregate) throws AuthenticationException;
@@ -72,7 +72,7 @@
      * @return the AuthenticationInfo object that will be presented to further realms in the authentication process - returning
      *         the <code>aggregate</code> method argument is the normal case if no special action needs to be taken.
-     * @throws org.apache.ki.authc.AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
+     * @throws org.apache.shiro.authc.AuthenticationException an exception thrown by the Strategy implementation if it wishes the login
      *                                 process for the associated subject (user) to stop immediately.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/FirstSuccessfulStrategy.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/FirstSuccessfulStrategy.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/ModularRealmAuthenticator.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/ModularRealmAuthenticator.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -25,19 +25,19 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AbstractAuthenticator;
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.LogoutAware;
-import org.apache.ki.authc.UnknownAccountException;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AbstractAuthenticator;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.LogoutAware;
+import org.apache.shiro.authc.UnknownAccountException;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * A <tt>ModularRealmAuthenticator</tt> delgates account lookups to a pluggable (modular) collection of
  * {@link Realm}s.  This enables PAM (Pluggable Authentication Module) behavior in Ki.
  * In addition to authorization duties, a Ki Realm can also be thought of a PAM 'module'.
  *
  * <p>Using this Authenticator allows you to &quot;plug-in&quot; your own
  * <tt>Realm</tt>s as you see fit.  Common realms are those based on accessing
@@ -45,7 +45,7 @@
  *
  * <p>If only one realm is configured (this is often the case for most applications), authentication success is naturally
  * only dependent upon invoking this one Realm's
- * {@link Realm#getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)} method.
+ * {@link Realm#getAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken)} method.
  *
  * <p>But if two or more realms are configured, PAM behavior is implemented by iterating over the collection of realms
  * and interacting with each over the course of the authentication attempt.  As this is more complicated, this
@@ -280,11 +280,11 @@
 
     /**
      * <p>Attempts to authenticate the given token by iterating over the internal collection of
-     * {@link Realm}s.  For each realm, first the {@link Realm#supports(org.apache.ki.authc.AuthenticationToken)}
+     * {@link Realm}s.  For each realm, first the {@link Realm#supports(org.apache.shiro.authc.AuthenticationToken)}
      * method will be called to determine if the realm supports the <tt>authenticationToken</tt> method argument.
      *
      * If a realm does support
-     * the token, its {@link Realm#getAuthenticationInfo(org.apache.ki.authc.AuthenticationToken)}
+     * the token, its {@link Realm#getAuthenticationInfo(org.apache.shiro.authc.AuthenticationToken)}
      * method will be called.  If the realm returns a non-null account, the token will be
      * considered authenticated for that realm and the account data recorded.  If the realm returns <tt>null</tt>,
      * the next realm will be consulted.  If no realms support the token or all supporting realms return null,
@@ -316,7 +316,7 @@
      * <code>((LogoutAware)realm).onLogout(principals)</code> to allow each realm the opportunity to perform
      * logout/cleanup operations during an user-logout.
      *
      * <p>Ki's Realm implementations all implement the <tt>LogoutAware</tt> interface by default and can be
      * overridden for realm-specific logout logic.
      *
      * @param principals the application-specific Subject/user identifier.
@@ -25,19 +25,19 @@
 /**
  * A <tt>ModularRealmAuthenticator</tt> delgates account lookups to a pluggable (modular) collection of
- * {@link Realm}s.  This enables PAM (Pluggable Authentication Module) behavior in Ki.
- * In addition to authorization duties, a Ki Realm can also be thought of a PAM 'module'.
+ * {@link Realm}s.  This enables PAM (Pluggable Authentication Module) behavior in Shiro.
+ * In addition to authorization duties, a Shiro Realm can also be thought of a PAM 'module'.
  *
  * <p>Using this Authenticator allows you to &quot;plug-in&quot; your own
@@ -316,7 +316,7 @@
      * logout/cleanup operations during an user-logout.
      *
-     * <p>Ki's Realm implementations all implement the <tt>LogoutAware</tt> interface by default and can be
+     * <p>Shiro's Realm implementations all implement the <tt>LogoutAware</tt> interface by default and can be
      * overridden for realm-specific logout logic.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/UnsupportedTokenException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/UnsupportedTokenException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/UnsupportedTokenException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/UnsupportedTokenException.java Thu Jun 18 03:13:34 2009
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
 
-import org.apache.ki.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationException;
 
 
 /**
  * Exception thrown during the authentication process when an
  * {@link org.apache.ki.authc.AuthenticationToken AuthenticationToken} implementation is encountered that is not
  * supported by one or more configured {@link org.apache.ki.realm.Realm Realm}s.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.authc.pam.AuthenticationStrategy
+ * @see org.apache.shiro.authc.pam.AuthenticationStrategy
  * @since 0.2
  */
 public class UnsupportedTokenException extends AuthenticationException {
@@ -16,18 +16,18 @@
 /**
  * Exception thrown during the authentication process when an
- * {@link org.apache.ki.authc.AuthenticationToken AuthenticationToken} implementation is encountered that is not
- * supported by one or more configured {@link org.apache.ki.realm.Realm Realm}s.
+ * {@link org.apache.shiro.authc.AuthenticationToken AuthenticationToken} implementation is encountered that is not
+ * supported by one or more configured {@link org.apache.shiro.realm.Realm Realm}s.
  *
  * @author Les Hazlewood

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authc/pam/package-info.java Thu Jun 18 03:13:34 2009
@@ -18,10 +18,10 @@
  */
 /**
  * Support for <em>PAM</em>, or <b>P</b>luggable <b>A</b>uthentication <b>M</b>odules, which is
  * the capability to authenticate a user against multiple configurable (pluggable) <em>modules</em> (Ki
  * calls these {@link org.apache.ki.realm.Realm Realm}s).
  * <p/>
- * The primary class of interest here is the {@link org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}
+ * The primary class of interest here is the {@link org.apache.shiro.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}
  * which is an <code>Authenticator</code> implementation that coordinates authentication attempts across
  * one or more Realm instances.
  * <p/>
@@ -29,4 +29,4 @@
  * application's needs using an injectible
  * {@link AuthenticationStrategy}.
  */
-package org.apache.ki.authc.pam;
+package org.apache.shiro.authc.pam;
@@ -18,10 +18,10 @@
 /**
  * Support for <em>PAM</em>, or <b>P</b>luggable <b>A</b>uthentication <b>M</b>odules, which is
- * the capability to authenticate a user against multiple configurable (pluggable) <em>modules</em> (Ki
- * calls these {@link org.apache.ki.realm.Realm Realm}s).
+ * the capability to authenticate a user against multiple configurable (pluggable) <em>modules</em> (Shiro
+ * calls these {@link org.apache.shiro.realm.Realm Realm}s).
  * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationInfo.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizationInfo.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.io.Serializable;
 import java.util.Collection;
@@ -32,29 +32,29 @@
  * <ul>
  * <li>A <code>Collection</code> of Strings, where each String can usually be converted into <code>Permission</code>
  * objects by a <code>Realm</code>'s
- * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}</li>
+ * {@link org.apache.shiro.authz.permission.PermissionResolver PermissionResolver}</li>
  * <li>A <code>Collection</code> of {@link Permission Permission} objects</li>
  * </ul>
  * Both permission collections together represent the total aggregate collection of permissions.  You may use one
  * or both depending on your preference and needs.
  * <p/>
  * Because the act of authorization (access control) is orthoganal to authentication (log-in), this interface is
  * intended to represent only the account data needed by Ki during an access control check
  * (role, permission, etc).  Ki also has a parallel
  * {@link org.apache.ki.authc.AuthenticationInfo AuthenticationInfo} interface for use during the authentication
  * process that represents identity data such as principals and credentials.
  * <p/>
  * Because many if not most {@link org.apache.ki.realm.Realm Realm}s store both sets of data for a Subject, it might be
  * convenient for a <code>Realm</code> implementation to utilize an implementation of the
  * {@link org.apache.ki.authc.Account Account} interface instead, which is a convenience interface that combines both
  * <code>AuthenticationInfo</code> and <code>AuthorizationInfo</code>.  Whether you choose to implement these two
  * interfaces separately or implement the one <code>Account</code> interface for a given <code>Realm</code> is
  * entirely based on your application's needs or your preferences.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
  * @see org.apache.ki.authc.AuthenticationInfo AuthenticationInfo
  * @see org.apache.ki.authc.Account
  * @since 0.9
  */
 public interface AuthorizationInfo extends Serializable {
@@ -74,10 +74,10 @@
      * This method is a convenience mechanism that allows Realms to represent permissions as Strings if they choose.
      * When performing a security check, a <code>Realm</code> usually converts these strings to object
      * {@link Permission Permission}s via an internal
-     * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}
+     * {@link org.apache.shiro.authz.permission.PermissionResolver PermissionResolver}
      * in order to perform the actual permission check.  This is not a requirement of course, since <code>Realm</code>s
      * can perform security checks in whatever manner deemed necessary, but this explains the conversion mechanism that
      * most Ki Realms execute for string-based permission checks.
      *
      * @return all string-based permissions assigned to the corresponding Subject.
      */
@@ -32,29 +32,29 @@
  * <p/>
  * Because the act of authorization (access control) is orthoganal to authentication (log-in), this interface is
- * intended to represent only the account data needed by Ki during an access control check
- * (role, permission, etc).  Ki also has a parallel
- * {@link org.apache.ki.authc.AuthenticationInfo AuthenticationInfo} interface for use during the authentication
+ * intended to represent only the account data needed by Shiro during an access control check
+ * (role, permission, etc).  Shiro also has a parallel
+ * {@link org.apache.shiro.authc.AuthenticationInfo AuthenticationInfo} interface for use during the authentication
  * process that represents identity data such as principals and credentials.
  * <p/>
@@ -32,29 +32,29 @@
  * process that represents identity data such as principals and credentials.
  * <p/>
- * Because many if not most {@link org.apache.ki.realm.Realm Realm}s store both sets of data for a Subject, it might be
+ * Because many if not most {@link org.apache.shiro.realm.Realm Realm}s store both sets of data for a Subject, it might be
  * convenient for a <code>Realm</code> implementation to utilize an implementation of the
@@ -32,29 +32,29 @@
  * convenient for a <code>Realm</code> implementation to utilize an implementation of the
- * {@link org.apache.ki.authc.Account Account} interface instead, which is a convenience interface that combines both
+ * {@link org.apache.shiro.authc.Account Account} interface instead, which is a convenience interface that combines both
  * <code>AuthenticationInfo</code> and <code>AuthorizationInfo</code>.  Whether you choose to implement these two
  * interfaces separately or implement the one <code>Account</code> interface for a given <code>Realm</code> is
@@ -32,29 +32,29 @@
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.authc.AuthenticationInfo AuthenticationInfo
- * @see org.apache.ki.authc.Account
+ * @see org.apache.shiro.authc.AuthenticationInfo AuthenticationInfo
+ * @see org.apache.shiro.authc.Account
  * @since 0.9
  */
@@ -74,10 +74,10 @@
      * in order to perform the actual permission check.  This is not a requirement of course, since <code>Realm</code>s
      * can perform security checks in whatever manner deemed necessary, but this explains the conversion mechanism that
-     * most Ki Realms execute for string-based permission checks.
+     * most Shiro Realms execute for string-based permission checks.
      *
      * @return all string-based permissions assigned to the corresponding Subject.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Authorizer.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Authorizer.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Authorizer.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Authorizer.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.subject.PrincipalCollection;
 
 /**
  * An <tt>Authorizer</tt> performs authorization (access control) operations for any given Subject
@@ -37,8 +37,8 @@
  * {@link Permission Permission} instances. They are a convenience allowing the caller to use a String representation of
  * a {@link Permission Permission} if desired.  Most implementations of this interface will simply convert these
  * String values to {@link Permission Permission} instances and then just call the corresponding type-safe method.
  * (Ki's default implementations do String-to-Permission conversion for these methods using
  * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}s.)
  *
  * <p>These overloaded *Permission methods <em>do</em> forego type-saftey for the benefit of convenience and simplicity,
  * so you should choose which ones to use based on your preferences and needs.
@@ -37,8 +37,8 @@
  * a {@link Permission Permission} if desired.  Most implementations of this interface will simply convert these
  * String values to {@link Permission Permission} instances and then just call the corresponding type-safe method.
- * (Ki's default implementations do String-to-Permission conversion for these methods using
- * {@link org.apache.ki.authz.permission.PermissionResolver PermissionResolver}s.)
+ * (Shiro's default implementations do String-to-Permission conversion for these methods using
+ * {@link org.apache.shiro.authz.permission.PermissionResolver PermissionResolver}s.)
  *
  * <p>These overloaded *Permission methods <em>do</em> forego type-saftey for the benefit of convenience and simplicity,

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizingAccount.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizingAccount.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizingAccount.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/AuthorizingAccount.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.authc.Account;
+import org.apache.shiro.authc.Account;
 
 /**
  * An <tt>AuthorizingAccount</tt> is an {@link Account Account} that knows about its assiged roles and permissions
@@ -29,74 +29,74 @@
  * implementations that want to cache authorization state when doing an account lookup so multiple authorization checks
  * do not need to access the Realm's underlying data store repeatedly.
  * <p/>
  * Of course, an <tt>AuthorizingAccount</tt> concept is only a convenience mechansim if Ki account caching
  * is enabled.  Realm implementations are free to ignore this interface entirely and implement/override any of their
  * <tt>Realm</tt>'s {@link Authorizer Authorizer} methods to execute the authorization checks as they see fit.
  * ({@link org.apache.ki.realm.Realm Realm} is a sub-interface of {@link Authorizer Authorizer} and therefore must
  * implement those methods as well).
  * <p/>
  * <b>DEPRECATION NOTE</b>: This interface and its default {@link SimpleAuthorizingAccount SimpleAuthorizingAccount}
  * implementation is deprecated and will be removed prior to 1.0 being released.  Instead, either just
  * return an {@link Account} instance, or if you want fine-grained control over authorization behavior, extend
  * a subclass of {@link org.apache.ki.realm.AuthorizingRealm} and implement your own security checks in the
  * Realm itself instead of forcing this logic in your entity/domain classes where it could be error prone and
  * unnecessarily couple these objects to Ki.
  *
  * @author Jeremy Haile
  * @author Les Hazlewood
- * @see org.apache.ki.realm.AuthorizingRealm
+ * @see org.apache.shiro.realm.AuthorizingRealm
  * @since 0.9
  * @deprecated
  */
 public interface AuthorizingAccount extends Account {
 
     /**
-     * @see org.apache.ki.subject.Subject#isPermitted(Permission)
+     * @see org.apache.shiro.subject.Subject#isPermitted(Permission)
      */
     boolean isPermitted(Permission permission);
 
     /**
-     * @see org.apache.ki.subject.Subject#isPermitted(java.util.List)
+     * @see org.apache.shiro.subject.Subject#isPermitted(java.util.List)
      */
     boolean[] isPermitted(List<Permission> permissions);
 
     /**
-     * @see org.apache.ki.subject.Subject#isPermittedAll(java.util.Collection)
+     * @see org.apache.shiro.subject.Subject#isPermittedAll(java.util.Collection)
      */
     boolean isPermittedAll(Collection<Permission> permissions);
 
     /**
-     * @see org.apache.ki.subject.Subject#checkPermission(Permission)
+     * @see org.apache.shiro.subject.Subject#checkPermission(Permission)
      */
     void checkPermission(Permission permission) throws AuthorizationException;
 
     /**
-     * @see org.apache.ki.subject.Subject#checkPermissions(java.util.Collection)
+     * @see org.apache.shiro.subject.Subject#checkPermissions(java.util.Collection)
      */
     void checkPermissions(Collection<Permission> permissions) throws AuthorizationException;
 
     /**
-     * @see org.apache.ki.subject.Subject#hasRole(String)
+     * @see org.apache.shiro.subject.Subject#hasRole(String)
      */
     boolean hasRole(String roleIdentifier);
 
     /**
-     * @see org.apache.ki.subject.Subject#hasRoles(java.util.List)
+     * @see org.apache.shiro.subject.Subject#hasRoles(java.util.List)
      */
     boolean[] hasRoles(List<String> roleIdentifiers);
 
     /**
-     * @see org.apache.ki.subject.Subject#hasAllRoles(java.util.Collection)
+     * @see org.apache.shiro.subject.Subject#hasAllRoles(java.util.Collection)
      */
     boolean hasAllRoles(Collection<String> roleIdentifiers);
 
     /**
-     * @see org.apache.ki.subject.Subject#checkRole(String)
+     * @see org.apache.shiro.subject.Subject#checkRole(String)
      */
     void checkRole(String role);
 
     /**
-     * @see org.apache.ki.subject.Subject#checkRoles
+     * @see org.apache.shiro.subject.Subject#checkRoles
      */
     void checkRoles(Collection<String> roles);
 }
@@ -29,74 +29,74 @@
  * do not need to access the Realm's underlying data store repeatedly.
  * <p/>
- * Of course, an <tt>AuthorizingAccount</tt> concept is only a convenience mechansim if Ki account caching
+ * Of course, an <tt>AuthorizingAccount</tt> concept is only a convenience mechansim if Shiro account caching
  * is enabled.  Realm implementations are free to ignore this interface entirely and implement/override any of their
  * <tt>Realm</tt>'s {@link Authorizer Authorizer} methods to execute the authorization checks as they see fit.
@@ -29,74 +29,74 @@
  * is enabled.  Realm implementations are free to ignore this interface entirely and implement/override any of their
  * <tt>Realm</tt>'s {@link Authorizer Authorizer} methods to execute the authorization checks as they see fit.
- * ({@link org.apache.ki.realm.Realm Realm} is a sub-interface of {@link Authorizer Authorizer} and therefore must
+ * ({@link org.apache.shiro.realm.Realm Realm} is a sub-interface of {@link Authorizer Authorizer} and therefore must
  * implement those methods as well).
  * <p/>
@@ -29,74 +29,74 @@
  * implementation is deprecated and will be removed prior to 1.0 being released.  Instead, either just
  * return an {@link Account} instance, or if you want fine-grained control over authorization behavior, extend
- * a subclass of {@link org.apache.ki.realm.AuthorizingRealm} and implement your own security checks in the
+ * a subclass of {@link org.apache.shiro.realm.AuthorizingRealm} and implement your own security checks in the
  * Realm itself instead of forcing this logic in your entity/domain classes where it could be error prone and
@@ -29,74 +29,74 @@
  * Realm itself instead of forcing this logic in your entity/domain classes where it could be error prone and
- * unnecessarily couple these objects to Ki.
+ * unnecessarily couple these objects to Shiro.
  *
  * @author Jeremy Haile

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/HostUnauthorizedException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/HostUnauthorizedException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/ModularRealmAuthorizer.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/ModularRealmAuthorizer.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.authz.permission.PermissionResolver;
-import org.apache.ki.authz.permission.PermissionResolverAware;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authz.permission.PermissionResolver;
+import org.apache.shiro.authz.permission.PermissionResolverAware;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.subject.PrincipalCollection;
 
 
 /**
@@ -96,14 +96,14 @@
 
     /**
      * Sets the specified {@link PermissionResolver PermissionResolver} on <em>all</em> of the wrapped realms that
      * implement the {@link org.apache.ki.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
      * <p/>
      * Only call this method if you want the permission resolver to be passed to all realms that implement the
      * <code>PermissionResolver</code> interface.  If you do not want this to occur, the realms must
      * configure themselves individually (or be configured individually).
      *
      * @param permissionResolver the permissionResolver to set on all of the wrapped realms that implement the
-     *                           {@link org.apache.ki.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
+     *                           {@link org.apache.shiro.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
      */
     public void setPermissionResolver(PermissionResolver permissionResolver) {
         this.permissionResolver = permissionResolver;
@@ -112,10 +112,10 @@
 
     /**
      * Sets the internal {@link #getPermissionResolver} on any internal configured
      * {@link #getRealms Realms} that implement the {@link org.apache.ki.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
      * <p/>
      * This method is called after setting a permissionResolver on this ModularRealmAuthorizer via the
-     * {@link #setPermissionResolver(org.apache.ki.authz.permission.PermissionResolver) setPermissionResolver} method.
+     * {@link #setPermissionResolver(org.apache.shiro.authz.permission.PermissionResolver) setPermissionResolver} method.
      * <p/>
      * It is also called after setting one or more realms via the {@link #setRealms setRealms} method to allow these
      * newly available realms to be given the <code>PermissionResolver</code> already in use.
@@ -152,7 +152,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , String)} returns <code>true</code>,
+     * {@link Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , String)} returns <code>true</code>,
      * <code>false</code> otherwise.
      */
     public boolean isPermitted(PrincipalCollection principals, String permission) {
@@ -167,7 +167,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , Permission)} call returns <code>true</code>,
+     * {@link Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , Permission)} call returns <code>true</code>,
      * <code>false</code> otherwise.
      */
     public boolean isPermitted(PrincipalCollection principals, Permission permission) {
@@ -182,7 +182,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , String[])} call returns <code>true</code>,
+     * {@link Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , String[])} call returns <code>true</code>,
      * <code>false</code> otherwise.
      */
     public boolean[] isPermitted(PrincipalCollection principals, String... permissions) {
@@ -199,7 +199,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
      * {@link org.apache.ki.realm.Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , List)} call returns <code>true</code>,
      * <code>false</code> otherwise.
      */
     public boolean[] isPermitted(PrincipalCollection principals, List<Permission> permissions) {
@@ -218,7 +218,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , String)} call returns <code>true</code>
+     * {@link Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , String)} call returns <code>true</code>
      * for <em>all</em> of the specified string permissions, <code>false</code> otherwise.
      */
     public boolean isPermittedAll(PrincipalCollection principals, String... permissions) {
@@ -235,7 +235,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , Permission)} call returns <code>true</code>
+     * {@link Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , Permission)} call returns <code>true</code>
      * for <em>all</em> of the specified Permissions, <code>false</code> otherwise.
      */
     public boolean isPermittedAll(PrincipalCollection principals, Collection<Permission> permissions) {
@@ -251,7 +251,7 @@
     }
 
     /**
-     * If !{@link #isPermitted(org.apache.ki.subject.PrincipalCollection , String) isPermitted(permission)}, throws
+     * If !{@link #isPermitted(org.apache.shiro.subject.PrincipalCollection , String) isPermitted(permission)}, throws
      * an <code>UnauthorizedException</code> otherwise returns quietly.
      */
     public void checkPermission(PrincipalCollection principals, String permission) throws AuthorizationException {
@@ -262,7 +262,7 @@
     }
 
     /**
-     * If !{@link #isPermitted(org.apache.ki.subject.PrincipalCollection , Permission) isPermitted(permission)}, throws
+     * If !{@link #isPermitted(org.apache.shiro.subject.PrincipalCollection , Permission) isPermitted(permission)}, throws
      * an <code>UnauthorizedException</code> otherwise returns quietly.
      */
     public void checkPermission(PrincipalCollection principals, Permission permission) throws AuthorizationException {
@@ -273,7 +273,7 @@
     }
 
     /**
-     * If !{@link #isPermitted(org.apache.ki.subject.PrincipalCollection , String[]) isPermitted(permission)}, throws
+     * If !{@link #isPermitted(org.apache.shiro.subject.PrincipalCollection , String[]) isPermitted(permission)}, throws
      * an <code>UnauthorizedException</code> otherwise returns quietly.
      */
     public void checkPermissions(PrincipalCollection principals, String... permissions) throws AuthorizationException {
@@ -286,7 +286,7 @@
     }
 
     /**
-     * If !{@link #isPermitted(org.apache.ki.subject.PrincipalCollection , Permission) isPermitted(permission)} for
+     * If !{@link #isPermitted(org.apache.shiro.subject.PrincipalCollection , Permission) isPermitted(permission)} for
      * <em>all</em> the given Permissions, throws
      * an <code>UnauthorizedException</code> otherwise returns quietly.
      */
@@ -301,7 +301,7 @@
 
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link Realm#hasRole(org.apache.ki.subject.PrincipalCollection , String)} call returns <code>true</code>,
+     * {@link Realm#hasRole(org.apache.shiro.subject.PrincipalCollection , String)} call returns <code>true</code>,
      * <code>false</code> otherwise.
      */
     public boolean hasRole(PrincipalCollection principals, String roleIdentifier) {
@@ -315,7 +315,7 @@
     }
 
     /**
      * Calls {@link #hasRole(org.apache.ki.subject.PrincipalCollection , String)} for each role name in the specified
      * collection and places the return value from each call at the respective location in the returned array.
      */
     public boolean[] hasRoles(PrincipalCollection principals, List<String> roleIdentifiers) {
@@ -334,7 +334,7 @@
 
     /**
      * Returns <code>true</code> iff any of the configured realms'
      * {@link Realm#hasRole(org.apache.ki.subject.PrincipalCollection , String)} call returns <code>true</code> for
      * <em>all</em> roles specified, <code>false</code> otherwise.
      */
     public boolean hasAllRoles(PrincipalCollection principals, Collection<String> roleIdentifiers) {
@@ -348,7 +348,7 @@
     }
 
     /**
-     * If !{@link #hasRole(org.apache.ki.subject.PrincipalCollection , String) hasRole(role)}, throws
+     * If !{@link #hasRole(org.apache.shiro.subject.PrincipalCollection , String) hasRole(role)}, throws
      * an <code>UnauthorizedException</code> otherwise returns quietly.
      */
     public void checkRole(PrincipalCollection principals, String role) throws AuthorizationException {
@@ -359,7 +359,7 @@
     }
 
     /**
      * Calls {@link #checkRole(org.apache.ki.subject.PrincipalCollection , String) checkRole} for each role specified.
      */
     public void checkRoles(PrincipalCollection principals, Collection<String> roles) throws AuthorizationException {
         assertRealmsConfigured();
@@ -96,14 +96,14 @@
     /**
      * Sets the specified {@link PermissionResolver PermissionResolver} on <em>all</em> of the wrapped realms that
-     * implement the {@link org.apache.ki.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
+     * implement the {@link org.apache.shiro.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
      * <p/>
      * Only call this method if you want the permission resolver to be passed to all realms that implement the
@@ -112,10 +112,10 @@
     /**
      * Sets the internal {@link #getPermissionResolver} on any internal configured
-     * {@link #getRealms Realms} that implement the {@link org.apache.ki.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
+     * {@link #getRealms Realms} that implement the {@link org.apache.shiro.authz.permission.PermissionResolverAware PermissionResolverAware} interface.
      * <p/>
      * This method is called after setting a permissionResolver on this ModularRealmAuthorizer via the
@@ -199,7 +199,7 @@
     /**
      * Returns <code>true</code> if any of the configured realms'
-     * {@link org.apache.ki.realm.Realm#isPermitted(org.apache.ki.subject.PrincipalCollection , List)} call returns <code>true</code>,
+     * {@link org.apache.shiro.realm.Realm#isPermitted(org.apache.shiro.subject.PrincipalCollection , List)} call returns <code>true</code>,
      * <code>false</code> otherwise.
      */
@@ -315,7 +315,7 @@
 
     /**
-     * Calls {@link #hasRole(org.apache.ki.subject.PrincipalCollection , String)} for each role name in the specified
+     * Calls {@link #hasRole(org.apache.shiro.subject.PrincipalCollection , String)} for each role name in the specified
      * collection and places the return value from each call at the respective location in the returned array.
      */
@@ -334,7 +334,7 @@
     /**
      * Returns <code>true</code> iff any of the configured realms'
-     * {@link Realm#hasRole(org.apache.ki.subject.PrincipalCollection , String)} call returns <code>true</code> for
+     * {@link Realm#hasRole(org.apache.shiro.subject.PrincipalCollection , String)} call returns <code>true</code> for
      * <em>all</em> roles specified, <code>false</code> otherwise.
      */
@@ -359,7 +359,7 @@
 
     /**
-     * Calls {@link #checkRole(org.apache.ki.subject.PrincipalCollection , String) checkRole} for each role specified.
+     * Calls {@link #checkRole(org.apache.shiro.subject.PrincipalCollection , String) checkRole} for each role specified.
      */
     public void checkRoles(PrincipalCollection principals, Collection<String> roles) throws AuthorizationException {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Permission.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Permission.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Permission.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/Permission.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz;
+package org.apache.shiro.authz;
 
 /**
  * A Permission represents the ability to perform an action or access a resource.  A Permission is the most
@@ -27,7 +27,7 @@
  * Granting access to an application functionality or a particular resource is done by the application's security
  * configuration, typically by assigning Permissions to users, roles and/or groups.
  *
  * <p>Most typical systems are what the Ki team calls <em>role-based</em> in nature, where a role represents
  * common behavior for certain user types.  For example, a system might have an <em>Aministrator</em> role, a
  * <em>User</em> or <em>Guest</em> roles, etc.
  *
@@ -50,18 +50,18 @@
  * and groups can all be created, configured and/or deleted at runtime.  This enables  an extremely powerful security
  * model.
  *
  * <p>A benefit to Ki is that, although it assumes most systems are based on these types of static role or
  * dynamic role w/ permission schemes, it does not require a system to model their security data this way - all
  * Permission checks are relegated to {@link org.apache.ki.realm.Realm} implementations, and only those implementatons
  * really determine how a user 'has' a permission or not.  The Realm could use the semantics described here, or it
  * could utilize some other mechanism entirely - it is always up to the application developer.
  *
  * <p>Ki provides a very powerful default implementation of this interface in the form of the
  * {@link org.apache.ki.authz.permission.WildcardPermission WildcardPermission}.  We highly recommend that you
  * investigate this class before trying to implement your own <code>Permission</code>s.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.authz.permission.WildcardPermission WildcardPermission
+ * @see org.apache.shiro.authz.permission.WildcardPermission WildcardPermission
  * @since 0.2
  */
 public interface Permission {
@@ -27,7 +27,7 @@
  * configuration, typically by assigning Permissions to users, roles and/or groups.
  *
- * <p>Most typical systems are what the Ki team calls <em>role-based</em> in nature, where a role represents
+ * <p>Most typical systems are what the Shiro team calls <em>role-based</em> in nature, where a role represents
  * common behavior for certain user types.  For example, a system might have an <em>Aministrator</em> role, a
  * <em>User</em> or <em>Guest</em> roles, etc.
@@ -50,18 +50,18 @@
  * model.
  *
- * <p>A benefit to Ki is that, although it assumes most systems are based on these types of static role or
+ * <p>A benefit to Shiro is that, although it assumes most systems are based on these types of static role or
  * dynamic role w/ permission schemes, it does not require a system to model their security data this way - all
@@ -50,18 +50,18 @@
  * dynamic role w/ permission schemes, it does not require a system to model their security data this way - all
- * Permission checks are relegated to {@link org.apache.ki.realm.Realm} implementations, and only those implementatons
+ * Permission checks are relegated to {@link org.apache.shiro.realm.Realm} implementations, and only those implementatons
  * really determine how a user 'has' a permission or not.  The Realm could use the semantics described here, or it
  * could utilize some other mechanism entirely - it is always up to the application developer.
@@ -50,18 +50,18 @@
  * could utilize some other mechanism entirely - it is always up to the application developer.
  *
- * <p>Ki provides a very powerful default implementation of this interface in the form of the
- * {@link org.apache.ki.authz.permission.WildcardPermission WildcardPermission}.  We highly recommend that you
+ * <p>Shiro provides a very powerful default implementation of this interface in the form of the
+ * {@link org.apache.shiro.authz.permission.WildcardPermission WildcardPermission}.  We highly recommend that you
  * investigate this class before trying to implement your own <code>Permission</code>s.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizationInfo.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/SimpleAuthorizationInfo.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresAuthentication.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresAuthentication.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.authz.annotation;
+package org.apache.shiro.authz.annotation;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -29,10 +29,10 @@
  * {@link RequiresUser RequiresUser} annotation.
  * <p/>
  * This annotation basically ensures that
- * <code>{@link org.apache.ki.subject.Subject subject}.{@link org.apache.ki.subject.Subject#isAuthenticated() isAuthenticated()} === true</code>
+ * <code>{@link org.apache.shiro.subject.Subject subject}.{@link org.apache.shiro.subject.Subject#isAuthenticated() isAuthenticated()} === true</code>
  * <p/>
  * See the {@link RequiresUser RequiresUser} and
  * {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
  * explaination of why these two states are considered different.
  *
  * @see RequiresUser
@@ -29,10 +29,10 @@
  * <p/>
  * See the {@link RequiresUser RequiresUser} and
- * {@link org.apache.ki.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
+ * {@link org.apache.shiro.authc.RememberMeAuthenticationToken RememberMeAuthenticationToken} JavaDoc for an
  * explaination of why these two states are considered different.
  *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresGuest.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/authz/annotation/RequiresGuest.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================